@@ -1,14 +1,14 @@
 #![no_std]
 
-use core::sync::atomic::{AtomicBool, AtomicU64, Ordering::SeqCst};
+use core::sync::atomic::{AtomicBool, Ordering::SeqCst};
 use core::time::Duration;
 
 static USED: AtomicBool = AtomicBool::new(false);
-static TIME: AtomicU64 = AtomicU64::new(0);
+static mut TIME: u64 = 0;
 
 /// Nanosecond since `app start time` or `os start time`
 pub fn now() -> u64 {
-    TIME.load(SeqCst)
+    unsafe { TIME }
 }
 clock_source::register_clock_source!(now);
 
@@ -16,8 +16,10 @@ pub struct Tick {}
 impl Tick {
     /// returns nanosecond
     pub fn tick(&mut self, interval: Duration) -> u64 {
-        let old = TIME.fetch_add(interval.as_nanos() as u64, SeqCst);
-        old + interval.as_nanos() as u64
+        unsafe {
+            TIME += interval.as_nanos() as u64;
+            TIME
+        }
     }
 }
 pub fn take_tick() -> Option<Tick> {
